#
# spec file for package arc-gtk-theme
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _theme  Arc
%define _name   arc
Name:           arc-gtk-theme
Version:        20221218
Release:        1.4
Summary:        Arc GTK theme
License:        GPL-3.0-or-later
URL:            https://github.com/jnsh/arc-theme
Source:         https://github.com/jnsh/arc-theme/releases/download/%{version}/arc-theme-%{version}.tar.xz
BuildRequires:  cinnamon
BuildRequires:  fdupes
BuildRequires:  gnome-shell
BuildRequires:  meson >= 0.53
BuildRequires:  optipng
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  pkgconfig(gtk+-3.0)
BuildArch:      noarch

%description
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

%package -n metatheme-%{_name}-common
Summary:        Arc Common Theme Files
Recommends:     adwaita-icon-theme
Suggests:       gtk2-metatheme-%{_name} = %{version}
Suggests:       gtk3-metatheme-%{_name} = %{version}

%description -n metatheme-%{_name}-common
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

This package contains common files and themes for GNOME Shell,
Marco, Xfwm4, and Cinnamon.

%package -n gtk2-metatheme-%{_name}
Summary:        Arc GTK 2 Theme
Requires:       gtk2-engine-murrine
Requires:       metatheme-%{_name}-common = %{version}
Supplements:    (metatheme-%{_name}-common and gtk2)

%description -n gtk2-metatheme-%{_name}
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

This package contains the GTK 2 theme.

%package -n gtk3-metatheme-%{_name}
Summary:        Arc GTK 3 Theme
Requires:       gtk3
Requires:       metatheme-%{_name}-common = %{version}
Supplements:    (metatheme-%{_name}-common and gtk3)

%description -n gtk3-metatheme-%{_name}
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

This package contains the GTK 3 theme.

%package -n gtk4-metatheme-%{_name}
Summary:        Arc GTK 4 Theme
Requires:       gtk4
Requires:       metatheme-%{_name}-common = %{version}
Supplements:    (metatheme-%{_name}-common and gtk4)

%description -n gtk4-metatheme-%{_name}
Arc is a flat theme with transparent elements.
It supports MATE, GNOME, Budgie, Xfce, and Cinnamon.

This package contains the GTK 4 theme.

%prep
%setup -q -n %{_name}-theme-%{version}

%build
%meson
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_datadir}/

%files -n metatheme-%{_name}-common
%license COPYING
%doc AUTHORS README.md
%dir %{_datadir}/themes/%{_theme}*/
%exclude %{_datadir}/themes/%{_theme}*/gtk-?.0/
%{_datadir}/themes/%{_theme}*/*

%files -n gtk2-metatheme-%{_name}
%license COPYING
%doc AUTHORS README.md
%{_datadir}/themes/%{_theme}*/gtk-2.0/

%files -n gtk3-metatheme-%{_name}
%license COPYING
%doc AUTHORS README.md
%{_datadir}/themes/%{_theme}*/gtk-3.0/

%files -n gtk4-metatheme-%{_name}
%license COPYING
%doc AUTHORS README.md
%{_datadir}/themes/%{_theme}*/gtk-4.0/

%changelog
* Mon Apr  3 2023 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 20221218
  * Cinnamon theme:
  * Update for Cinnamon 5.4
  * GNOME Shell theme:
  * Update for GNOME Shell 43
  * Various fixes and updates for GNOME Shell 42
  * GTK 3 and GTK4 themes:
  * Fix "dark style" preference with Arc-Dark variant
  * Add borders to solid-csd decorations, fixing some borderless windows
  * GTK 3 theme:
  * Fix switches in xfce4-panel menus
  * Fix offset titlebar decorations in some cases
    (e.g. Cinnamon 5.4 and Electron applications in GNOME)
  * Various Fixes and improvements
* Sat Apr 30 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 20220405
  * GNOME Shell theme: Update for GNOME Shell 42
  * GTK 3 theme:
  * Nautilus path-bar improvements
  * Style redesigned path-bar in Nautilus 42
  * Various fixes
  * GTK 4 theme: Add libadwaita public color definitions
- Update to version 20220223
  * GTK 3 theme: Various fixes and improvements
  * GTK 4 theme:
  * Add styling for libadwaita widgets
  * Stop versioning the theme, as that seems unnecessary for GTK 4
  * Various fixes and improvements
  * GNOME Shell theme: Fix dash-to-dock focused application icon
    mouseover background
- Update to version 20220102
  * Cinnamon theme:
  * Update for Cinnamon 5.2
  * Drop support for versions before 3.8
  * GTK 4 theme: Fix applications crashing with GTK 4.6
  * GTK 3 theme:
  * Drop versioned themes, and only target GTK 3.24 for now on
  * Xfce4 panel padding fixes
  * Hide border on MATE panel sensors applet graph
  * GNOME Shell theme:
  * Drop Arc-Lighter variant for GNOME Shell 40 and later
  * Drop support for versions before 3.28
  * Metacity theme:
  * Add dark Metacity v3 variant, with distinct window border
  * Adjust titlebar padding
  * Increase rounded corner radius slightly
  * Don't round corners for tiled windows
  * Xfwm4 theme:
  * Increase resize border width
  * Make bottom decoration corners square
  * Fix titlebar button spacing
- Update to version 20211018
  * Added Arc GTK 4 theme: Currently based on GTK 4.2, but should
    work just as well with GTK 4.4. Any libadwaita specific styling
    is not yet supported, so applications using it may appear
    imperfectly themed.
  * GTK 3 theme:
  * Update style for libhandy
  * Fix circular buttons appearing elliptical
  * GNOME Shell theme:
  * Add support for GNOME Shell 41
  * Various updates and fixes for GNOME Shell 40
  * Cinnamon theme: Support version 5.01
* Wed May 12 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 20210412:
  + Support GNOME 40
  + Switch to meson build system.
- Replace autoconf and automake BuildRequires with meson.
* Thu May  7 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 20200502:
  * No changelog available.
- Build the Cinnamon theme.
- Switch to https://github.com/jnsh/arc-theme
* Tue Nov 19 2019 Petr Cervinka <petr@cervinka.net>
- Update to version 20190917:
  * Allow builds against gnome-shell 3.34
  * Refactor gnome-shell 3.32 code
  * Removes redundant selectors/styling (i.e. styling that is no longer
    required in newer gnome shell versions), and replaces with newer selectors/styling
    (modifying to match Arc styling where necessary)
  * Integrates styling from the default gnome shell theme into the Arc shell theme.
    Because the user shell theme (Arc in this case) is "overlaid" over the default shell
    theme, this is styling that was being "pulled in" anyway.
  * Add full shadows to panel dropdown menus
  * InfoBar colors should respect type
  * Remove border from stackswitcher
  * Don't hardcode LightDM font-size
  * XFCE 4.14 panel styling fixes
- Update GitHub project url from NicoHood to arc-design
- Update public keyring from  NicoHood <pgp@nicohood.de> to David Mohammed <fossfreedom@ubuntu.com>
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat May 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 20190330 (no changelog supplied)
- Fix build with gnome-shell 3.32 and newer
* Thu Oct 25 2018 sor.alexei@meowr.ru
- Update to version 20181022:
  * No changelog available.
- Use GPG signing.
* Mon Sep 10 2018 minava@t-online.de
- Update to version 20180715 (changes since 20180114):
  * Added openbox theme
  * Updated thunar style
  * Added inkscape and optipng dependencies
  * Bugfixes
* Thu May 31 2018 mati865@gmail.com
- Update to version 20180114
  * General cleanup of outdated gtk versions and extras
  * Readme update
  * Minor fixes for cinnamon and xfce4
  * Add budgie desktop styling #17
  * Slightly darken fonts for light theme to improve contrast #15
  * Switch building from gulp to sassc
  * Mate screensaver styling #27
  * Install plank theme with makefile directly
* Sun Mar 12 2017 matthias.eliasson@gmail.com
- Update to version 20170302
  * Cinnamon 3.2 fixes
  * Fix frame borders with GTK 3.22.9
  * Small bugfixes
* Tue Nov 22 2016 sor.alexei@meowr.ru
- Update to version 20161119:
  * Cinnamon 3.2 support.
  * Bugfixes.
* Sun Nov 13 2016 mailaender@opensuse.org
- Update to version 20161005
  * Fix OSD windows in MATE 1.16
  * Fix Unity window decorations with GTK 3.20
  * Minor bugfixes
* Sat Sep 24 2016 sor.alexei@meowr.ru
- Update to version 20160923:
  * GNOME 3.22 support.
  * elementary OS Loki support.
  * Improve GNOME Flashback support (3.20+ only).
  * Easier window resizing in Xfce and MATE.
  * Bugfixes.
* Sun Jun  5 2016 sor.alexei@meowr.ru
- Update to version 20160605 (changes since 20160331):
  * Use highlight colour for selected menuitems.
  * Add dark Chromium theme.
  * Merge xfce-notify theme with GTK+ 2 theme (this removes the
  - -disable-xfce-notify build option).
  * Fix bugs in GTK+ 2 entry styling.
  * Update Unity window decorations.
  * Bugfixes.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 20160331:
  * Lots of fixes for Gnome/GTK+ 3.20.
* Fri Mar 25 2016 sor.alexei@meowr.ru
- Initial package.
